Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Detective.

Actions, resources, and condition keys for Amazon Detective - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Detective

Amazon Detective (service prefix: `detective` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Detective
- Resource types defined by Amazon Detective
- Condition keys for Amazon Detective

## Actions defined by Amazon Detective

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AcceptInvitation | Grants permission to accept an invitation to become a member of a behavior graph | Write |  |  |
BatchGetGraphMemberDatasources | Grants permission to retrieve the datasource package history for the specified member accounts in a behavior graph managed by this account | Read | Graph* |  |
BatchGetMembershipDatasources | Grants permission to retrieve the datasource package history of the caller account for the specified graphs | Read |  |  |
CreateGraph | Grants permission to create a behavior graph and begin to aggregate security information | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateMembers | Grants permission to request the membership of one or more accounts in a behavior graph managed by this account | Write | Graph* |  |
DeleteGraph | Grants permission to delete a behavior graph and stop aggregating security information | Write | Graph* |  |
DeleteMembers | Grants permission to remove member accounts from a behavior graph managed by this account | Write | Graph* |  |
DescribeOrganizationConfiguration | Grants permission to view the current configuration related to the Amazon Detective integration with AWS Organizations | Read | Graph* |  | organizations:DescribeOrganization
DisableOrganizationAdminAccount | Grants permission to remove the Amazon Detective delegated administrator account for an organization | Write |  |  | organizations:DescribeOrganization
DisassociateMembership | Grants permission to remove the association of this account with a behavior graph | Write |  |  |
EnableOrganizationAdminAccount | Grants permission to designate the Amazon Detective delegated administrator account for an organization | Write |  |  | iam:CreateServiceLinkedRole organizations:DescribeOrganization organizations:EnableAWSServiceAccess organizations:RegisterDelegatedAdministrator
GetFreeTrialEligibility [permission only] | Grants permission to retrieve a behavior graph's eligibility for a free trial period | Read | Graph* |  |
GetGraphIngestState [permission only] | Grants permission to retrieve the data ingestion state of a behavior graph | Read | Graph* |  |
GetMembers | Grants permission to retrieve details on specified members of a behavior graph | Read | Graph* |  |
GetPricingInformation [permission only] | Grants permission to retrieve information about Amazon Detective's pricing | Read |  |  |
GetUsageInformation [permission only] | Grants permission to list usage information of a behavior graph | Read | Graph* |  |
ListDatasourcePackages | Grants permission to list a graph's datasource package ingest states and timestamps for the most recent state changes in a behavior graph managed by this account | List | Graph* |  |
ListGraphs | Grants permission to list behavior graphs managed by this account | List |  |  |
ListHighDegreeEntities [permission only] | Grants permission to retrieve high volume entities whose relationships cannot be stored by Detective | List | Graph* |  |
ListInvitations | Grants permission to retrieve details on the behavior graphs to which this account has been invited to join | List |  |  |
ListMembers | Grants permission to retrieve details on all members of a behavior graph | List | Graph* |  |
ListOrganizationAdminAccount | Grants permission to view the current Amazon Detective delegated administrator account for an organization | List |  |  | organizations:DescribeOrganization
ListTagsForResource | Grants permission to list the tag values that are assigned to a behavior graph | List | Graph* |  |
| aws:ResourceTag/${TagKey} |
RejectInvitation | Grants permission to reject an invitation to become a member of a behavior graph | Write |  |  |
SearchGraph [permission only] | Grants permission to search the data stored in a behavior graph | Read | Graph* |  |
StartMonitoringMember | Grants permission to start data ingest for a member account that has a status of ACCEPTED_BUT_DISABLED | Write | Graph* |  |
TagResource | Grants permission to assign tag values to a behavior graph | Tagging | Graph* |  |
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UntagResource | Grants permission to remove tag values from a behavior graph | Tagging | Graph* |  |
| aws:TagKeys |
UpdateDatasourcePackages | Grants permission to enable or disable datasource package(s) in a behavior graph managed by this account | Write | Graph* |  |
UpdateOrganizationConfiguration | Grants permission to update the current configuration related to the Amazon Detective integration with AWS Organizations | Write | Graph* |  | organizations:DescribeOrganization

## Resource types defined by Amazon Detective

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
Graph | `arn:$ { Partition}:detective:$ { Region}:$ { Account}:graph:$ { ResourceId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Detective

Amazon Detective defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by specifying the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by specifying the tags associated with the resource | String
aws:TagKeys | Filters access by specifying the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.